==> openGion6.9.7.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GEA09S.sql <==
/****************************************************************************/
/* GEA09 ( ﾕｰｻﾞｰｱｸｾｽ画面管理ﾃｰﾌﾞﾙ )                                         */
/*                                                                          */
/* Created : 2017/01/05 15:19:02                                            */
/****************************************************************************/

CREATE TABLE GEA09 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID       */
 , USERID       VARCHAR (  10 )                 NOT NULL                                                /*  20 ﾕｰｻﾞｰID      */
 , GUIKEY       VARCHAR (  30 )                 NOT NULL                                                /*  30 画面ID       */
 , SEQNO        INTEGER             DEFAULT 0   NOT NULL                                                /*  40 表示順       */
 , NAME_JA      VARCHAR ( 200 )                                                                         /*  50 名称         */
 , LAST_ACCESS  VARCHAR (  14 )                                                                         /*  60 最終ｱｸｾｽ時間 */
 , FGFAVORITE   VARCHAR (   1 )                                                                         /*  70 ｵ気ﾆ入ﾘ      */
 , CLASSIFY     VARCHAR ( 120 )                                                                         /*  80 分類         */
 , NEXTGUI      TEXT                                                                                    /*  90 次画面ﾘｽﾄ    */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者       */
);

==> openGion7.0.3.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GEA09S.sql <==
/****************************************************************************/
/* GEA09 ( ﾕｰｻﾞｰｱｸｾｽ画面管理ﾃｰﾌﾞﾙ )                                         */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GEA09 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID       */
 , USERID       VARCHAR (  10 )                 NOT NULL                                                /*  20 ﾕｰｻﾞｰID      */
 , GUIKEY       VARCHAR (  30 )                 NOT NULL                                                /*  30 画面ID       */
 , SEQNO        INTEGER             DEFAULT 0   NOT NULL                                                /*  40 表示順       */
 , NAME_JA      VARCHAR ( 200 )                                                                         /*  50 名称         */
 , LAST_ACCESS  VARCHAR (  14 )                                                                         /*  60 最終ｱｸｾｽ時間 */
 , FGFAVORITE   VARCHAR (   1 )                                                                         /*  70 お気に入り   */
 , CLASSIFY     VARCHAR ( 120 )                                                                         /*  80 分類         */
 , NEXTGUI      TEXT                                                                                    /*  90 次画面ﾘｽﾄ    */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者       */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者       */
);
